rkeops options in R global options scoperkeops uses two sets of options: compile options (see
compile_options()) and runtime options (see
runtime_options()). These options define the behavior of rkeops
when compiling or when calling user-defined operators.
You can read the current states of rkeops options by calling
get_rkeops_options().
get_rkeops_options(tag = NULL)a list with rkeops current options values (see Details).
text string being "compile" or "runtime" to get corresponding
options. If missing (default), both are returned.
Ghislain Durif
rkeops global options includes two lists defining options used at
compilation of user-defined operators or at runtime. These two list
contains specific informations (see compile_options() and
runtime_options() respectively, in particular for default values).
If the tag input parameter is specified (e.g. "compile" or "runtime"),
only the corresponding option list is returned.
These options are set with the functions set_rkeops_options() and
set_rkeops_option(). To know which values are allowed for which
options, you can check compile_options() and
runtime_options().
get_rkeops_option(), compile_options(),
runtime_options(), set_rkeops_options(),
set_rkeops_option()
library(rkeops)
get_rkeops_options()
Run the code above in your browser using DataLab