rkeops option namesThe function rkeops_option_names returns the names of the different
rkeops option (in R global options scope).
rkeops_option_names(tag = c("compile", "runtime"))a vector of requested rkeops options.
text string or vector of text string, specifying the requested
subset of rkeops options, i.e. "compile" or "runtime". Default value
is c("compile", "runtime") and both are returned.
Ghislain Durif
rkeops uses two sets of options: compile options
(see compile_options()), and runtime options
(see runtime_options()).
These options define the behavior of rkeops when compiling or when
calling user-defined operators.
You can specify a tag ("compile" or "runtime" or both) in input, you
will get the names of the corresponding subset of rkeops options.
get_rkeops_options(), set_rkeops_options(),
compile_options(), runtime_options()