rkeops options in R global options scoperkeops uses two sets of options: compile options (see
compile_options()) and runtime options (see
runtime_options()). These options define the behavior of rkeops
when compiling or when calling user-defined operators.
If no input is provided, the functions set_rkeops_options initializes the
rkeops options in the R global options scope (i.e. options available
by calling options() or getOptions(<option_name>)) with default values.
If some input is provided, i.e. objects defining compile options and/or
runtime options (see Details), rkeops global options are updated
accordingly.
set_rkeops_options(
custom_compile_options = NULL,
custom_runtime_options = NULL
)None
a list (of class rkeops_compile_options).
See compile_options() for a detailled description. Default value
is NULL and default compile options are set up (see
default_compile_options()).
a list (of class rkeops_runtime_options).
See runtime_options() for a detailled description. Default
value is NULL and default runtime options are set up
(see default_runtime_options()).
Ghislain Durif
rkeops global options includes two lists defining options used at
compilation of user-defined operators or at runtime. These two list
contains specific informations (see compile_options() and
runtime_options() respectively, in particular for default values).
In order to update, the corresponding options, user should provide objects
returned by the functions compile_options() and/or
runtime_options() respectively, being lists of class
rkeops_compile_options and rkeops_runtime_options respectively, with
specific attributes.
set_rkeops_option(), compile_options(),
runtime_options(), default_compile_options(),
default_runtime_options(), use_gpu(),
compile4gpu(), get_rkeops_options()